@@ -3225,7 +3225,7 @@ Exp_OverlayObjCmd(
     int newfd, oldfd;
     int dash_name = 0;
     char *command;
-    int k;
+    int k, j;
     char **argv;
 
     int i;
@@ -3265,25 +3265,29 @@ Exp_OverlayObjCmd(
 	return(TCL_ERROR);
     }
 
-    /* convert to string array for execvp */
+    /* convert to string array for execvp.
+     * Take only the arguments after the command name (i+1 ...). The arguments
+     * before are arguments of overlay, not of the invoked command. The
+     * command name is at index.
+     */
 
     argv = (char**) ckalloc ((objc+1)*sizeof(char*));
 
-    for (k=1;k<objc;k++) {
-	argv[k] = ckalloc (1+strlen(Tcl_GetString (objv[k])));
-	strcpy (argv[k],Tcl_GetString (objv[k]));
+    for (k=i+1,j=1;k<objc;k++,j++) {
+	argv[j] = ckalloc (1+strlen(Tcl_GetString (objv[k])));
+	strcpy (argv[j],Tcl_GetString (objv[k]));
     }
-    argv[objc] = NULL;
+    argv[j] = NULL;
 
     /* command, handle '-' */
-    argv[0] = ckalloc (2+strlen(Tcl_GetString (objv[0])));
+    command = Tcl_GetString (objv[i]);
+    argv[0] = ckalloc (2+strlen(command));
     if (dash_name) {
 	argv [0][0] = '-';
-	strcpy (argv[0]+1,Tcl_GetString (objv[0]));
+	strcpy (argv[0]+1,command);
     } else {
-	strcpy (argv[0],Tcl_GetString (objv[0]));
+	strcpy (argv[0],command);
     }
-    command = Tcl_GetString (objv[0]);
 
     signal(SIGINT, SIG_DFL);
     signal(SIGQUIT, SIG_DFL);
