@@ -724,19 +724,23 @@ struct eval_out {
 Tcl_UniChar *
 string_case_first(	/* INTL */
     register Tcl_UniChar *string,	/* String (unicode). */
+    int length,                         /* length of above string */
     register char *pattern)	/* Pattern, which may contain
 				 * special characters (utf8). */
 {
     Tcl_UniChar *s;
     char *p;
     int offset;
+    register int consumed = 0;
     Tcl_UniChar ch1, ch2;
-    
-    while (*string != 0) {
+    Tcl_UniChar *bufend = string + length;
+
+    while ((*string != 0) && (string < bufend)) {
 	s = string;
 	p = pattern;
-	while (*s) {
+        while ((*s) && (s < bufend)) {
 	    ch1 = *s++;
+            consumed++;
 	    offset = TclUtfToUniChar(p, &ch2);
 	    if (Tcl_UniCharToLower(ch1) != Tcl_UniCharToLower(ch2)) {
 		break;
@@ -747,36 +751,42 @@ string_case_first(	/* INTL */
 	    return string;
 	}
 	string++;
+        consumed++;
     }
     return NULL;
 }
 
 Tcl_UniChar *
 string_first(	/* INTL */
-    register Tcl_UniChar *string,	/* String (unicode). */
-    register char *pattern)	/* Pattern, which may contain
-				 * special characters (utf8). */
+    register Tcl_UniChar *string,       /* String (unicode). */
+    int length,                         /* length of above string */
+    register char *pattern)             /* Pattern, which may contain
+                                         * special characters (utf8). */
 {
     Tcl_UniChar *s;
     char *p;
     int offset;
+    register int consumed = 0;
     Tcl_UniChar ch1, ch2;
+    Tcl_UniChar *bufend = string + length;
     
-    while (*string != 0) {
+    while ((*string != 0) && (string < bufend)) {
 	s = string;
 	p = pattern;
-	while (*s) {
+        while ((*s) && (s < bufend)) {
 	    ch1 = *s++;
+            consumed++;
 	    offset = TclUtfToUniChar(p, &ch2);
 	    if (ch1 != ch2) {
 		break;
 	    }
 	    p += offset;
 	}
-	if (*p == '\0') {
+        if (*p == '\0') {
 	    return string;
 	}
-	string++;
+        string++;
+        consumed++;
     }
     return NULL;
 }
@@ -927,9 +937,9 @@ eval_case_string(
 	Tcl_UniChar *p;
 
 	if (e->Case == CASE_NORM) {
-	    p = string_first(str, pat); /* NEW function in this file, see above */
+	    p = string_first(str, numchars, pat); /* NEW function in this file, see above */
 	} else {
-	    p = string_case_first(str, pat);
+	    p = string_case_first(str, numchars, pat);
 	}	    
 
 	expDiagLog("\"");
